==> unicore-gateway-6.4.0-2.src.tar.gz: src/main/java/eu/unicore/gateway/properties/JettyProperties.java <==
/**
 * Copyright (c) 2005, Forschungszentrum Juelich
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met: 
 * 
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the Forschungszentrum Juelich nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package eu.unicore.gateway.properties;

import java.io.File;
import java.util.HashMap;
import java.util.HashSet;


public class JettyProperties extends RProperties
{
	public static final File FILE_JETTY_PROPERTIES = GatewayProperties.FILE_GATEWAY_PROPERTIES;

	/**
	 * Should the NIO connector be used?
	 * NIO is best suited under high-load, when lots of connections
	 * exist that are idle for long periods.
	 * 
	 * default: false
	 */
	public static final String USE_NIO = "jetty.useNIO";


	/**
	 * minimum nuber of threads to have in the Jetty thread pool (default: 1)
	 */
	public static final String MIN_THREADS = "jetty.minThreads";

	/**
	 * maximum nuber of threads to have in the Jetty thread pool (default: 255)
	 */
	public static final String MAX_THREADS = "jetty.maxThreads";

	/**
	 * lowThreads is a threshold indicator.  If the available number 
	 * of threads in the pool dips under this value (especially when max 
	 * threads is reached), per connection max idle time will be cut 
	 * from normal to low-resource
	 * (default: 50)
	 */
	public static final String LOW_THREADS = "jetty.lowThreads";

	/**
	 * time (in ms.) before an idle connection will time out (default: 3000)
	 */
	public static final String MAX_IDLE_TIME = "jetty.maxIdleTime";

	/**
	 * in low resource conditions, time (in ms.) before an idle connection will time out (default: 100)
	 * @see #LOW_THREADS
	 */
	public static final String LOW_RESOURCE_MAX_IDLE_TIME = "jetty.lowResourceMaxIdleTime";

	/**
	 * run AJP connector instead of the usual socket connector
	 * 
	 */
	public static final String ENABLE_AJP = "jetty.ajp";

	public static String GZIPCONFIG_PREFIX="gateway.jetty.gzip.";
	
	public static final String MIN_GZIP_SIZE=GZIPCONFIG_PREFIX+".minGzipSize";
	public static final String ENABLE_GZIP=GZIPCONFIG_PREFIX+".enable";

	/**
	 * use java.util.Random to generate session ids instead of SecureRandom
	 * default: true
	 */
	public static final String FAST_RANDOM = "jetty.fastRandom";

	
	protected static HashMap<String,Integer>defaults=new HashMap<String, Integer>();
	
	static{
		defaults.put(MAX_THREADS, 255);
		defaults.put(MIN_THREADS, 1);
		defaults.put(LOW_THREADS, 50);
		defaults.put(MAX_IDLE_TIME, 3000);
		defaults.put(LOW_RESOURCE_MAX_IDLE_TIME, 100);
	}

	
	public JettyProperties(String name)
	{
		super(name, new HashSet<String>());
	}

	public JettyProperties(File f)
	{
		super(f, new HashSet<String>());
	}
	
	public boolean isJettyGzipEnabled()
	{
		return getPropertyAsBool(ENABLE_GZIP, true);
	}
	
	public String getGzipProperty(String name)
	{
		return getStringProperty(GZIPCONFIG_PREFIX + name, null);
	}
	
	public int getIntProperty(String pName)
	{
		return getPropertyAsInt(pName, defaults.get(pName));
	} 
	
	public boolean getBooleanProperty(String pName, boolean defaultValue)
	{
		return getPropertyAsBool(pName, defaultValue);
	} 
}

==> unicore-gateway6-4.3.0-2.src.tar.gz: src/main/java/eu/unicore/gateway/properties/JettyProperties.java <==
/**
 * Copyright (c) 2005, Forschungszentrum Juelich
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met: 
 * 
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the Forschungszentrum Juelich nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package eu.unicore.gateway.properties;

import java.io.File;
import java.util.HashMap;
import java.util.HashSet;


public class JettyProperties extends RProperties
{
	public static final File FILE_JETTY_PROPERTIES = GatewayProperties.FILE_GATEWAY_PROPERTIES;

	/**
	 * Should the NIO connector be used?
	 * NIO is best suited under high-load, when lots of connections
	 * exist that are idle for long periods.
	 * 
	 * default: false
	 */
	public static final String USE_NIO = "jetty.useNIO";


	/**
	 * minimum nuber of threads to have in the Jetty thread pool (default: 1)
	 */
	public static final String MIN_THREADS = "jetty.minThreads";

	/**
	 * maximum nuber of threads to have in the Jetty thread pool (default: 255)
	 */
	public static final String MAX_THREADS = "jetty.maxThreads";

	/**
	 * lowThreads is a threshold indicator.  If the available number 
	 * of threads in the pool dips under this value (especially when max 
	 * threads is reached), per connection max idle time will be cut 
	 * from normal to low-resource
	 * (default: 50)
	 */
	public static final String LOW_THREADS = "jetty.lowThreads";

	/**
	 * time (in ms.) before an idle connection will time out (default: 3000)
	 */
	public static final String MAX_IDLE_TIME = "jetty.maxIdleTime";

	/**
	 * in low resource conditions, time (in ms.) before an idle connection will time out (default: 100)
	 * @see #LOW_THREADS
	 */
	public static final String LOW_RESOURCE_MAX_IDLE_TIME = "jetty.lowResourceMaxIdleTime";

	/**
	 * run AJP connector instead of the usual socket connector
	 * 
	 */
	public static final String ENABLE_AJP = "jetty.ajp";

	public static final String GZIPCONFIG_PREFIX="gateway.jetty.gzip.";
	
	public static final String MIN_GZIP_SIZE=GZIPCONFIG_PREFIX+".minGzipSize";
	public static final String ENABLE_GZIP=GZIPCONFIG_PREFIX+".enable";

	/**
	 * use java.util.Random to generate session ids instead of SecureRandom
	 * default: true
	 */
	public static final String FAST_RANDOM = "jetty.fastRandom";

	
	protected final static HashMap<String,Integer>defaults=new HashMap<String, Integer>();
	
	static{
		defaults.put(MAX_THREADS, 255);
		defaults.put(MIN_THREADS, 1);
		defaults.put(LOW_THREADS, 50);
		defaults.put(MAX_IDLE_TIME, 3000);
		defaults.put(LOW_RESOURCE_MAX_IDLE_TIME, 100);
	}

	
	public JettyProperties(String name)
	{
		super(name, new HashSet<String>());
	}

	public JettyProperties(File f)
	{
		super(f, new HashSet<String>());
	}
	
	public boolean isJettyGzipEnabled()
	{
		return getPropertyAsBool(ENABLE_GZIP, true);
	}
	
	public String getGzipProperty(String name)
	{
		return getStringProperty(GZIPCONFIG_PREFIX + name, null);
	}
	
	public int getIntProperty(String pName)
	{
		return getPropertyAsInt(pName, defaults.get(pName));
	} 
	
	public boolean getBooleanProperty(String pName, boolean defaultValue)
	{
		return getPropertyAsBool(pName, defaultValue);
	} 
}
